@@ -1,6 +1,7 @@
 import re
-from typing import Optional
 from collections import namedtuple
+from typing import Optional
+
 from attrs import define, field
 
 BACKTICKS = "```"
@@ -44,7 +45,7 @@ class Mapping:
     etl_after_insert: Optional[str] = field(default=None)
 
     column_mappings: list[ColumnMapping] = field(factory=list)
-    attached_rules: list[str] = field(default=list)
+    attached_rules: list[str] = field(factory=list)
     etl_prep_steps: list[str] = field(factory=list)
     etl_post_steps: list[str] = field(factory=list)
 
@@ -142,7 +143,7 @@ def _is_in_square_brackets(line: str) -> Optional[KeyAndVal]:
     return _is_key_val_property(line, throws_on_fail=True)
 
 
-def from_markdown(text: str, filter=filter_keep_code) -> Mapping:
+def from_markdown(text: str) -> Mapping:
     """
     Parses a markdown file and returns mapping.
 
@@ -214,19 +215,24 @@ def from_markdown(text: str, filter=filter_keep_code) -> Mapping:
         if len(line_buffer) > 0:
             stored_value = "\n".join(line_buffer)
         else:
-            stored_value = kv.val.lstrip()
+            stored_value = kv.val.lstrip()  # pyright: ignore
 
         # if column_mapping exists, we are modifying the column mapping
         if colmap and colmap.column != "":
             match property:
                 case "MAPPED_TO":
                     colmap.mapped_to = stored_value
-                case ("TO2_PDM_EDW.ETL_TRANSFORMATION_RULE" | "TO2_PDM_EDW.ETL_TRANSFORMATION_RULES"):
+                case (
+                    "TO2_PDM_EDW.ETL_TRANSFORMATION_RULE"
+                    | "TO2_PDM_EDW.ETL_TRANSFORMATION_RULES"
+                ):
                     colmap.transformation_rule = stored_value
                 case "COMMENT":
                     colmap.comment = stored_value
                 case _:
-                    raise ParsingError(f"unknown property for column mapping {colmap.column}: {property}")
+                    raise ParsingError(
+                        f"unknown property for column mapping {colmap.column}: {property}"
+                    )
 
             line_buffer = []
             continue
