@@ -1,11 +1,13 @@
-import sys
-import subprocess
 import json
+import subprocess
+import sys
 from pathlib import Path
-from attrs import define, field
-import cattr
 
-__SUPPORTED_PLATFORMS__ = ["win32"]
+import cattr
+from attrs import define, field
+from loguru import logger
+
+__SUPPORTED_PLATFORMS__ = ["win32", "linux"]
 
 assert sys.platform in __SUPPORTED_PLATFORMS__, f"unsupported platform: {sys.platform}"
 
@@ -24,6 +26,8 @@ class Rules:
 class Column:
     name: str = field(default="")
     comment: str = field(default="")
+    primary: bool = field(default=False)
+    mandatory: bool = field(default=False)
     data_type: str = field(default="")
     data_type_base: str = field(default="")
     scale: int = field(default=None)
@@ -37,7 +41,6 @@ class Column:
     compress: str = field(default="")
     character_set: str = field(default="")
     case_specific: bool = field(default=False)
-    primary: bool = field(default=False)
     etl_src_not_available: bool = field(default=False)
     etl_crc_format: str = field(default="")
     etl_src_header: str = field(default="")
@@ -54,7 +57,7 @@ class Table:
     name: str = field(default="")
     comment: str = field(default="")
     set_or_multiset: str = field(default="")
-    columns: list[Column] = field(default="")
+    columns: list[Column] = field(factory=list)
     pi_name: str = field(default=None)
     pi_is_upi: bool = field(default=False)
     pi_columns: list[str] = field(default=list())
@@ -173,18 +176,17 @@ def from_file(filename: str | Path, timeout_seconds=2) -> list[Table] | Table:
             jsonizer, stderr=subprocess.STDOUT, timeout=timeout_seconds
         )
     except subprocess.TimeoutExpired:
-        raise subprocess.TimeoutExpired(
-            f"timeout: {_table2json.name} did not finish in under {timeout_seconds} seconds: check the file {filename}"
-        )
+        logger.error(f"{_table2json}: timeout, neskončil včas, chyba?")
+        raise
     except subprocess.CalledProcessError:
-        raise subprocess.CalledProcessError(
-            f"error: {_table2json.name} returned error, check the file {filename}"
-        )
+        logger.error(f"{_table2json}: skončil s chybou")
+        raise
 
     # get the json
     output_string = output_bytes.decode("utf-8")
     # get the table
     tables_list = json.loads(output_string)
     tables = cattr.structure(tables_list, list[Table])
-
+    if len(tables) == 1:
+        return tables[0]
     return tables
